@@ -21,6 +21,7 @@
 #include <kdbtypes.h>
 #ifdef ELEKTRA_ENABLE_OPTIMIZATIONS
 #include <kdbopmphm.h>
+#include <kdbopmphmpredictor.h>
 #endif
 #include <kdbglobal.h>
 
@@ -67,6 +68,7 @@ typedef struct _Trie Trie;
 typedef struct _Split Split;
 typedef struct _Backend Backend;
 
+
 /* These define the type for pointers to all the kdb functions */
 typedef int (*kdbOpenPtr) (Plugin *, Key * errorKey);
 typedef int (*kdbClosePtr) (Plugin *, Key * errorKey);
@@ -84,7 +86,10 @@ typedef int (*CloseMapper) (Backend *);
  * Key Flags
  *****************/
 
-enum { KEY_EMPTY_NAME = 1 << 22 };
+enum
+{
+	KEY_EMPTY_NAME = 1 << 22
+};
 
 // clang-format off
 
@@ -115,12 +120,26 @@ typedef enum {
 			 to be changed. All attempts to change the value
 			 will lead to an error.
 			 Needed for metakeys*/
-	KEY_FLAG_RO_META = 1 << 3	/*!<
+	KEY_FLAG_RO_META = 1 << 3,	/*!<
 			 Read only flag for meta.
 			 Key meta is read only and not allowed
 			 to be changed. All attempts to change the value
 			 will lead to an error.
 			 Needed for metakeys.*/
+	KEY_FLAG_MMAP_STRUCT = 1 << 4,	/*!<
+			 Key struct lies inside a mmap region.
+			 This flag is set for Keys inside a mapped region.
+			 It prevents erroneous free() calls on these keys. */
+	KEY_FLAG_MMAP_KEY = 1 << 5,	/*!<
+			 Key name lies inside a mmap region.
+			 This flag is set once a Key name has been moved to a mapped region,
+			 and is removed if the name moves out of the mapped region.
+			 It prevents erroneous free() calls on these keys. */
+	KEY_FLAG_MMAP_DATA = 1 << 6	/*!<
+			 Key value lies inside a mmap region.
+			 This flag is set once a Key value has been moved to a mapped region,
+			 and is removed if the value moves out of the mapped region.
+			 It prevents erroneous free() calls on these keys. */
 } keyflag_t;
 
 
@@ -138,6 +157,21 @@ typedef enum {
 		 If keys were popped from the Keyset
 		 this flag will be set, so that the backend will sync
 		 the keys to database.*/
+#ifdef ELEKTRA_ENABLE_OPTIMIZATIONS
+	,KS_FLAG_NAME_CHANGE = 1 << 1 /*!<
+		 The OPMPHM needs to be rebuild.
+		 Every Key add, Key removal or Key name change operation
+		 sets this flag.*/
+#endif
+	,KS_FLAG_MMAP_STRUCT = 1 << 2	/*!<
+		 KeySet struct lies inside a mmap region.
+		 This flag is set for KeySets inside a mapped region.
+		 It prevents erroneous free() calls on these KeySets. */
+	,KS_FLAG_MMAP_ARRAY = 1 << 3	/*!<
+		 Array of the KeySet lies inside a mmap region.
+		 This flag is set for KeySets where the array is in a mapped region,
+		 and is removed if the array is moved out from the mapped region.
+		 It prevents erroneous free() calls on these arrays. */
 } ksflag_t;
 
 
@@ -237,11 +271,16 @@ struct _KeySet
 	 * Some control and internal flags.
 	 */
 	ksflag_t flags;
+
 #ifdef ELEKTRA_ENABLE_OPTIMIZATIONS
 	/**
 	 * The Order Preserving Minimal Perfect Hash Map.
 	 */
 	Opmphm * opmphm;
+	/**
+	 * The Order Preserving Minimal Perfect Hash Map Predictor.
+	 */
+	OpmphmPredictor * opmphmPredictor;
 #endif
 };
 
@@ -424,6 +463,7 @@ struct _Split
 	splitflag_t * syncbits; /*!< Bits for various options, see #splitflag_t for documentation */
 };
 
+
 // clang-format on
 
 /***************************************
