@@ -40,7 +40,7 @@
  * Initialize everything with zero, except: sizes with -1
  * and refcounter with 1
  *
- * @return 
+ * @return
  */
 static Backend * elektraBackendAllocate (void)
 {
@@ -426,10 +426,8 @@ int backendUpdateSize (Backend * backend, Key * parent, int size)
 		return -1;
 	}
 
-#if DEBUG && VERBOSE
-	printf ("user: %zd\n", backend->usersize);
-	printf ("system: %zd\n", backend->systemsize);
-#endif
+	ELEKTRA_LOG_DEBUG ("user: %zd", backend->usersize);
+	ELEKTRA_LOG_DEBUG ("system: %zd", backend->systemsize);
 
 	return 0;
 }
