@@ -503,7 +503,8 @@ ssize_t keySetMeta (Key * key, const char * metaName, const char * newMetaString
 			return -1;
 		}
 
-		if (toSet->data.v) elektraFree (toSet->data.v);
+		if (toSet->data.v && !test_bit (toSet->flags, KEY_FLAG_MMAP_DATA)) elektraFree (toSet->data.v);
+		clear_bit (toSet->flags, KEY_FLAG_MMAP_DATA);
 		toSet->data.c = metaStringDup;
 		toSet->dataSize = metaStringSize;
 	}
