@@ -17,7 +17,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-typedef enum {
+typedef enum
+{
 	PREF = 0,
 	USER,
 	LOCK,
