@@ -21,7 +21,8 @@
 
 #define ID_MAX_CHARACTERS 11
 
-typedef enum {
+typedef enum
+{
 	NAME,
 	UID,
 } SortBy;
@@ -48,6 +49,75 @@ static int validatepwent (struct passwd * pwd)
 	return 0;
 }
 
+#if defined(USE_FGETPWENT_LOCAL)
+// clang-format off
+/* Taken from musl libc
+ *
+ * https://github.com/ifduyue/musl/blob/b4b1e10364c8737a632be61582e05a8d3acf5690/src/passwd/getpwent_a.c
+ * https://github.com/ifduyue/musl/blob/b4b1e10364c8737a632be61582e05a8d3acf5690/src/passwd/fgetpwent.c
+ */
+
+static unsigned atou(char **s)
+{
+	unsigned x;
+	for (x=0; (unsigned char)(**s-'0')<10U; ++*s) x=10*x+((unsigned char)**s-'0');
+	return x;
+}
+
+int __getpwent_a(FILE *f, struct passwd *pw, char **line, size_t *size, struct passwd **res)
+{
+	ssize_t l;
+	char *s;
+	int rv = 0;
+	for (;;) {
+		if ((l=getline(line, size, f)) < 0) {
+			rv = ferror(f) ? errno : 0;
+			free(*line);
+			*line = 0;
+			pw = 0;
+			break;
+		}
+		line[0][l-1] = 0;
+
+		s = line[0];
+		pw->pw_name = s++;
+		if (!(s = strchr(s, ':'))) continue;
+
+		*s++ = 0; pw->pw_passwd = s;
+		if (!(s = strchr(s, ':'))) continue;
+
+		*s++ = 0; pw->pw_uid = atou(&s);
+		if (*s != ':') continue;
+
+		*s++ = 0; pw->pw_gid = atou(&s);
+		if (*s != ':') continue;
+
+		*s++ = 0; pw->pw_gecos = s;
+		if (!(s = strchr(s, ':'))) continue;
+
+		*s++ = 0; pw->pw_dir = s;
+		if (!(s = strchr(s, ':'))) continue;
+
+		*s++ = 0; pw->pw_shell = s;
+		break;
+	}
+	*res = pw;
+	if (rv) errno = rv;
+	return rv;
+}
+
+struct passwd *fgetpwent_l(FILE *f)
+{
+	static char *line;
+	static struct passwd pw;
+	size_t size=0;
+	struct passwd *res;
+	__getpwent_a(f, &pw, &line, &size, &res);
+	return res;
+}
+// clang-format on
+#endif
+
 static KeySet * pwentToKS (struct passwd * pwd, Key * parentKey, SortBy index)
 {
 	KeySet * ks = ksNew (0, KS_END);
@@ -129,26 +199,25 @@ int elektraPasswdGet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned ELEKTRA_
 	else
 		index = UID;
 	struct passwd * pwd;
-#if HAS_FGETPWENT
 	FILE * pwfile = fopen (keyString (parentKey), "r");
 	if (!pwfile)
 	{
 		ELEKTRA_SET_ERRORF (110, parentKey, "Failed to open configuration file %s\n", keyString (parentKey));
 		return -1;
 	}
+#if defined(USE_FGETPWENT)
 	while ((pwd = fgetpwent (pwfile)) != NULL)
+#elif defined(USE_FGETPWENT_LOCAL)
+	while ((pwd = fgetpwent_l (pwfile)) != NULL)
 #else
-	while ((pwd = getpwent ()) != NULL)
+#error Configuration error in CMakeLists.txt. Neither fgetpwent nor getline were provided. Please open an issue at https://issue.libelektra.org.
 #endif
 	{
 		KeySet * ks = pwentToKS (pwd, parentKey, index);
 		ksAppend (returned, ks);
 		ksDel (ks);
 	}
-	endpwent ();
-#if HAS_FGETPWENT
 	fclose (pwfile);
-#endif
 	return 1; // success
 }
 
@@ -245,7 +314,7 @@ static int writeKS (KeySet * returned, Key * parentKey, SortBy index)
 		}
 		else
 		{
-#if HAS_PUTPWENT
+#if defined(USE_PUTPWENT)
 			putpwent (pwd, pwfile);
 #else
 			fprintf (pwfile, "%s:%s:%u:%u:%s:%s:%s\n", pwd->pw_name, pwd->pw_passwd, pwd->pw_uid, pwd->pw_gid, pwd->pw_gecos,
@@ -287,7 +356,7 @@ int elektraPasswdSet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned ELEKTRA_
 Plugin * ELEKTRA_PLUGIN_EXPORT (passwd)
 {
 	// clang-format off
-    return elektraPluginExport ("passwd",
+	return elektraPluginExport ("passwd",
 	    ELEKTRA_PLUGIN_GET,	&elektraPasswdGet,
 	    ELEKTRA_PLUGIN_SET,	&elektraPasswdSet,
 	    ELEKTRA_PLUGIN_END);
