@@ -7,8 +7,7 @@ echo
 check_version
 
 FILE="$(mktempfile_elektra)"
-cleanup()
-{
+cleanup() {
 	rm -f "$FILE"
 }
 
@@ -23,8 +22,7 @@ fi
 
 printf "Checking %s\n" "$ACTUAL_PLUGINS"
 
-for PLUGIN in $ACTUAL_PLUGINS
-do
+for PLUGIN in $ACTUAL_PLUGINS; do
 	case "$PLUGIN" in
 	'jni')
 		# References:
@@ -51,21 +49,13 @@ do
 		;;
 	esac
 
-	# The following checks fail on an ASAN enabled build
-	# See also: https://github.com/ElektraInitiative/libelektra/pull/1963
 	ASAN='@ENABLE_ASAN@'
 	if [ "$ASAN" = 'ON' ]; then
+		# Do not check plugins with known memory leaks in ASAN enabled build
+		"$KDB" info "$PLUGIN" status 2> /dev/null | egrep -q 'memleak' && continue
+
 		case "$PLUGIN" in
-		'crypto_gcrypt')
-			continue
-			;;
-		'crypto_botan')
-			continue
-			;;
-		'xerces')
-			continue
-			;;
-		'ruby')
+		'augeas') # Reference: https://travis-ci.org/sanssecours/elektra/jobs/418524229
 			continue
 			;;
 		esac
@@ -76,7 +66,7 @@ do
 	succeed_if "check of plugin $PLUGIN failed"
 
 	test ! -s $FILE
-	succeed_if "check of plugin $PLUGIN produced: \"`cat $FILE`\""
+	succeed_if "check of plugin $PLUGIN produced: \"$(cat $FILE)\""
 done
 
 end_script basic commands
