@@ -6,17 +6,15 @@ echo
 
 check_version
 
-check_wrong_export()
-{
-	WC=`grep -r "ELEKTRA_PLUGIN_$1" "$2" | wc -l`
+check_wrong_export() {
+	WC=$(grep -r "ELEKTRA_PLUGIN_$1" "$2" | wc -l)
 	[ $WC -le 1 ]
 	succeed_if "It is likely that you are resetting a function pointer $WC times in your export, please use the word ELEKTRA_PLUGIN_$1 only once in your plugin $2"
 }
 
 PLUGINS_DIR="@CMAKE_SOURCE_DIR@/src/plugins"
 
-for PLUGIN in `ls "$PLUGINS_DIR"`
-do
+for PLUGIN in $(ls "$PLUGINS_DIR"); do
 	PLUGIN_DIR="$PLUGINS_DIR/$PLUGIN"
 
 	if [ ! -d "$PLUGIN_DIR" ]; then
@@ -25,7 +23,7 @@ do
 	echo "Do in-source check for plugin $PLUGIN"
 
 	README="$PLUGINS_DIR/README.md"
-	WC=`grep "^- \\[$PLUGIN\\]($PLUGIN/)" "$README"  | wc -l`
+	WC=$(grep "^- \[$PLUGIN\]($PLUGIN/)" "$README" | wc -l)
 	[ $WC -eq 1 ]
 	succeed_if "Your plugin $PLUGIN does not have an entry ^- [$PLUGIN]($PLUGIN/) in $README"
 
@@ -42,8 +40,6 @@ do
 		check_wrong_export ERROR "$PLUGIN_DIR"
 	fi
 
-
-
 done
 
 end_script plugins
